@@ -6,8 +6,18 @@ from hcloud.core.domain import add_meta_to_result
 from hcloud.firewalls.client import BoundFirewall
 from hcloud.floating_ips.client import BoundFloatingIP
 from hcloud.isos.client import BoundIso
-from hcloud.servers.domain import Server, CreateServerResponse, ResetPasswordResponse, EnableRescueResponse, \
-    RequestConsoleResponse, PublicNetwork, IPv4Address, IPv6Network, PrivateNet, PublicNetworkFirewall
+from hcloud.servers.domain import (
+    Server,
+    CreateServerResponse,
+    ResetPasswordResponse,
+    EnableRescueResponse,
+    RequestConsoleResponse,
+    PublicNetwork,
+    IPv4Address,
+    IPv6Network,
+    PrivateNet,
+    PublicNetworkFirewall,
+)
 from hcloud.volumes.client import BoundVolume
 from hcloud.images.domain import CreateImageResponse
 from hcloud.images.client import BoundImage
@@ -22,49 +32,74 @@ class BoundServer(BoundModelBase):
 
     def __init__(self, client, data, complete=True):
 
-        datacenter = data.get('datacenter')
+        datacenter = data.get("datacenter")
         if datacenter is not None:
-            data['datacenter'] = BoundDatacenter(client._client.datacenters, datacenter)
+            data["datacenter"] = BoundDatacenter(client._client.datacenters, datacenter)
 
-        volumes = data.get('volumes', [])
+        volumes = data.get("volumes", [])
         if volumes:
-            volumes = [BoundVolume(client._client.volumes, {"id": volume}, complete=False) for volume in volumes]
-            data['volumes'] = volumes
+            volumes = [
+                BoundVolume(client._client.volumes, {"id": volume}, complete=False)
+                for volume in volumes
+            ]
+            data["volumes"] = volumes
 
         image = data.get("image", None)
         if image is not None:
-            data['image'] = BoundImage(client._client.images, image)
+            data["image"] = BoundImage(client._client.images, image)
 
         iso = data.get("iso", None)
         if iso is not None:
-            data['iso'] = BoundIso(client._client.isos, iso)
+            data["iso"] = BoundIso(client._client.isos, iso)
 
         server_type = data.get("server_type")
         if server_type is not None:
-            data['server_type'] = BoundServerType(client._client.server_types, server_type)
+            data["server_type"] = BoundServerType(
+                client._client.server_types, server_type
+            )
 
         public_net = data.get("public_net")
         if public_net:
-            ipv4_address = IPv4Address(**public_net['ipv4'])
-            ipv6_network = IPv6Network(**public_net['ipv6'])
-            floating_ips = [BoundFloatingIP(client._client.floating_ips, {"id": floating_ip}, complete=False) for
-                            floating_ip in public_net['floating_ips']]
+            ipv4_address = IPv4Address.from_dict(public_net["ipv4"])
+            ipv6_network = IPv6Network.from_dict(public_net["ipv6"])
+            floating_ips = [
+                BoundFloatingIP(
+                    client._client.floating_ips, {"id": floating_ip}, complete=False
+                )
+                for floating_ip in public_net["floating_ips"]
+            ]
             firewalls = [
                 PublicNetworkFirewall(
-                    BoundFirewall(client._client.firewalls, {"id": firewall["id"]}, complete=False),
-                    status=firewall["status"]
-                ) for firewall in public_net.get("firewalls", [])
+                    BoundFirewall(
+                        client._client.firewalls, {"id": firewall["id"]}, complete=False
+                    ),
+                    status=firewall["status"],
+                )
+                for firewall in public_net.get("firewalls", [])
             ]
-            data['public_net'] = PublicNetwork(ipv4=ipv4_address, ipv6=ipv6_network, floating_ips=floating_ips,
-                                               firewalls=firewalls)
+            data["public_net"] = PublicNetwork(
+                ipv4=ipv4_address,
+                ipv6=ipv6_network,
+                floating_ips=floating_ips,
+                firewalls=firewalls,
+            )
 
         private_nets = data.get("private_net")
         if private_nets:
-            private_nets = [PrivateNet(
-                network=BoundNetwork(client._client.networks, {"id": private_net['network']}, complete=False),
-                ip=private_net['ip'], alias_ips=private_net['alias_ips'], mac_address=private_net['mac_address']) for
-                private_net in private_nets]
-            data['private_net'] = private_nets
+            private_nets = [
+                PrivateNet(
+                    network=BoundNetwork(
+                        client._client.networks,
+                        {"id": private_net["network"]},
+                        complete=False,
+                    ),
+                    ip=private_net["ip"],
+                    alias_ips=private_net["alias_ips"],
+                    mac_address=private_net["mac_address"],
+                )
+                for private_net in private_nets
+            ]
+            data["private_net"] = private_nets
 
         super(BoundServer, self).__init__(client, data, complete)
 
@@ -100,12 +135,12 @@ class BoundServer(BoundModelBase):
         # type: (Optional[str], Optional[Dict[str, str]]) -> BoundServer
         """Updates a server. You can update a server’s name and a server’s labels.
 
-         :param name: str (optional)
-                New name to set
-         :param labels: Dict[str, str] (optional)
-                User-defined labels (key-value pairs)
-         :return: :class:`BoundServer <hcloud.servers.client.BoundServer>`
-         """
+        :param name: str (optional)
+               New name to set
+        :param labels: Dict[str, str] (optional)
+               User-defined labels (key-value pairs)
+        :return: :class:`BoundServer <hcloud.servers.client.BoundServer>`
+        """
         return self._client.update(self, name, labels)
 
     def delete(self):
@@ -158,7 +193,7 @@ class BoundServer(BoundModelBase):
 
     def reset_password(self):
         # type: () -> ResetPasswordResponse
-        """ Resets the root password. Only works for Linux systems that are running the qemu guest agent.
+        """Resets the root password. Only works for Linux systems that are running the qemu guest agent.
 
         :return: :class:`ResetPasswordResponse <hcloud.servers.domain.ResetPasswordResponse>`
         """
@@ -322,7 +357,7 @@ class BoundServer(BoundModelBase):
 
 
 class ServersClient(ClientEntityBase, GetEntityByNameMixin):
-    results_list_attribute_name = 'servers'
+    results_list_attribute_name = "servers"
 
     def get_by_id(self, id):
         # type: (int) -> BoundServer
@@ -331,16 +366,19 @@ class ServersClient(ClientEntityBase, GetEntityByNameMixin):
         :param id: int
         :return: :class:`BoundServer <hcloud.servers.client.BoundServer>`
         """
-        response = self._client.request(url="/servers/{server_id}".format(server_id=id), method="GET")
-        return BoundServer(self, response['server'])
+        response = self._client.request(
+            url="/servers/{server_id}".format(server_id=id), method="GET"
+        )
+        return BoundServer(self, response["server"])
 
-    def get_list(self,
-                 name=None,  # type: Optional[str]
-                 label_selector=None,  # type: Optional[str]
-                 page=None,  # type: Optional[int]
-                 per_page=None,  # type: Optional[int]
-                 status=None,  # type: Optional[List[str]]
-                 ):
+    def get_list(
+        self,
+        name=None,  # type: Optional[str]
+        label_selector=None,  # type: Optional[str]
+        page=None,  # type: Optional[int]
+        per_page=None,  # type: Optional[int]
+        status=None,  # type: Optional[List[str]]
+    ):
         # type: (...) -> PageResults[List[BoundServer], Meta]
         """Get a list of servers from this account
 
@@ -358,19 +396,21 @@ class ServersClient(ClientEntityBase, GetEntityByNameMixin):
         """
         params = {}
         if name is not None:
-            params['name'] = name
+            params["name"] = name
         if label_selector is not None:
-            params['label_selector'] = label_selector
+            params["label_selector"] = label_selector
         if status is not None:
             params["status"] = status
         if page is not None:
-            params['page'] = page
+            params["page"] = page
         if per_page is not None:
-            params['per_page'] = per_page
+            params["per_page"] = per_page
 
         response = self._client.request(url="/servers", method="GET", params=params)
 
-        ass_servers = [BoundServer(self, server_data) for server_data in response['servers']]
+        ass_servers = [
+            BoundServer(self, server_data) for server_data in response["servers"]
+        ]
         return self._add_meta_to_result(ass_servers, response)
 
     def get_all(self, name=None, label_selector=None, status=None):
@@ -385,7 +425,9 @@ class ServersClient(ClientEntityBase, GetEntityByNameMixin):
                Can be used to filter servers by their status. The response will only contain servers matching the status.
         :return: List[:class:`BoundServer <hcloud.servers.client.BoundServer>`]
         """
-        return super(ServersClient, self).get_all(name=name, label_selector=label_selector, status=status)
+        return super(ServersClient, self).get_all(
+            name=name, label_selector=label_selector, status=status
+        )
 
     def get_by_name(self, name):
         # type: (str) -> BoundServer
@@ -397,21 +439,22 @@ class ServersClient(ClientEntityBase, GetEntityByNameMixin):
         """
         return super(ServersClient, self).get_by_name(name)
 
-    def create(self,
-               name,  # type: str
-               server_type,  # type: ServerType
-               image,  # type: Image
-               ssh_keys=None,  # type: Optional[List[SSHKey]]
-               volumes=None,  # type: Optional[List[Volume]]
-               firewalls=None,  # type: Optional[List[Firewall]]
-               networks=None,  # type: Optional[List[Network]]
-               user_data=None,  # type: Optional[str]
-               labels=None,  # type: Optional[Dict[str, str]]
-               location=None,  # type: Optional[Location]
-               datacenter=None,  # type: Optional[Datacenter]
-               start_after_create=True,  # type: Optional[bool]
-               automount=None  # type: Optional[bool]
-               ):
+    def create(
+        self,
+        name,  # type: str
+        server_type,  # type: ServerType
+        image,  # type: Image
+        ssh_keys=None,  # type: Optional[List[SSHKey]]
+        volumes=None,  # type: Optional[List[Volume]]
+        firewalls=None,  # type: Optional[List[Firewall]]
+        networks=None,  # type: Optional[List[Network]]
+        user_data=None,  # type: Optional[str]
+        labels=None,  # type: Optional[Dict[str, str]]
+        location=None,  # type: Optional[Location]
+        datacenter=None,  # type: Optional[Datacenter]
+        start_after_create=True,  # type: Optional[bool]
+        automount=None,  # type: Optional[bool]
+    ):
         # type: (...) -> CreateServerResponse
         """Creates a new server. Returns preliminary information about the server as well as an action that covers progress of creation.
 
@@ -440,42 +483,47 @@ class ServersClient(ClientEntityBase, GetEntityByNameMixin):
         :return: :class:`CreateServerResponse <hcloud.servers.domain.CreateServerResponse>`
         """
         data = {
-            'name': name,
-            'server_type': server_type.id_or_name,
+            "name": name,
+            "server_type": server_type.id_or_name,
             "start_after_create": start_after_create,
-            "image": image.id_or_name
+            "image": image.id_or_name,
         }
 
         if location is not None:
-            data['location'] = location.id_or_name
+            data["location"] = location.id_or_name
         if datacenter is not None:
-            data['datacenter'] = datacenter.id_or_name
+            data["datacenter"] = datacenter.id_or_name
         if ssh_keys is not None:
-            data['ssh_keys'] = [ssh_key.id_or_name for ssh_key in ssh_keys]
+            data["ssh_keys"] = [ssh_key.id_or_name for ssh_key in ssh_keys]
         if volumes is not None:
-            data['volumes'] = [volume.id for volume in volumes]
+            data["volumes"] = [volume.id for volume in volumes]
         if networks is not None:
-            data['networks'] = [network.id for network in networks]
+            data["networks"] = [network.id for network in networks]
         if firewalls is not None:
-            data['firewalls'] = [{"firewall": firewall.id} for firewall in firewalls]
+            data["firewalls"] = [{"firewall": firewall.id} for firewall in firewalls]
         if user_data is not None:
-            data['user_data'] = user_data
+            data["user_data"] = user_data
         if labels is not None:
-            data['labels'] = labels
+            data["labels"] = labels
         if automount is not None:
             data["automount"] = automount
 
         response = self._client.request(url="/servers", method="POST", json=data)
 
         result = CreateServerResponse(
-            server=BoundServer(self, response['server']),
-            action=BoundAction(self._client.actions, response['action']),
-            next_actions=[BoundAction(self._client.actions, action) for action in response['next_actions']],
-            root_password=response['root_password']
+            server=BoundServer(self, response["server"]),
+            action=BoundAction(self._client.actions, response["action"]),
+            next_actions=[
+                BoundAction(self._client.actions, action)
+                for action in response["next_actions"]
+            ],
+            root_password=response["root_password"],
         )
         return result
 
-    def get_actions_list(self, server, status=None, sort=None, page=None, per_page=None):
+    def get_actions_list(
+        self, server, status=None, sort=None, page=None, per_page=None
+    ):
         # type: (Server, Optional[List[str]], Optional[List[str]], Optional[int], Optional[int]) -> PageResults[List[BoundAction], Meta]
         """Returns all action objects for a server.
 
@@ -500,10 +548,16 @@ class ServersClient(ClientEntityBase, GetEntityByNameMixin):
         if per_page is not None:
             params["per_page"] = per_page
 
-        response = self._client.request(url="/servers/{server_id}/actions".format(server_id=server.id), method="GET",
-                                        params=params)
-        actions = [BoundAction(self._client.actions, action_data) for action_data in response['actions']]
-        return add_meta_to_result(actions, response, 'actions')
+        response = self._client.request(
+            url="/servers/{server_id}/actions".format(server_id=server.id),
+            method="GET",
+            params=params,
+        )
+        actions = [
+            BoundAction(self._client.actions, action_data)
+            for action_data in response["actions"]
+        ]
+        return add_meta_to_result(actions, response, "actions")
 
     def get_actions(self, server, status=None, sort=None):
         # type: (Server, Optional[List[str]], Optional[List[str]]) -> List[BoundAction]
@@ -534,8 +588,12 @@ class ServersClient(ClientEntityBase, GetEntityByNameMixin):
             data.update({"name": name})
         if labels is not None:
             data.update({"labels": labels})
-        response = self._client.request(url="/servers/{server_id}".format(server_id=server.id), method="PUT", json=data)
-        return BoundServer(self, response['server'])
+        response = self._client.request(
+            url="/servers/{server_id}".format(server_id=server.id),
+            method="PUT",
+            json=data,
+        )
+        return BoundServer(self, response["server"])
 
     def delete(self, server):
         # type: (Server) -> BoundAction
@@ -544,8 +602,10 @@ class ServersClient(ClientEntityBase, GetEntityByNameMixin):
         :param server: :class:`BoundServer <hcloud.servers.client.BoundServer>` or :class:`Server <hcloud.servers.domain.Server>`
         :return:  :class:`BoundAction <hcloud.actions.client.BoundAction>`
         """
-        response = self._client.request(url="/servers/{server_id}".format(server_id=server.id), method="DELETE")
-        return BoundAction(self._client.actions, response['action'])
+        response = self._client.request(
+            url="/servers/{server_id}".format(server_id=server.id), method="DELETE"
+        )
+        return BoundAction(self._client.actions, response["action"])
 
     def power_off(self, server):
         # type: (Server) -> Action
@@ -554,9 +614,11 @@ class ServersClient(ClientEntityBase, GetEntityByNameMixin):
         :param server: :class:`BoundServer <hcloud.servers.client.BoundServer>` or :class:`Server <hcloud.servers.domain.Server>`
         :return:  :class:`BoundAction <hcloud.actions.client.BoundAction>`
         """
-        response = self._client.request(url="/servers/{server_id}/actions/poweroff".format(server_id=server.id),
-                                        method="POST")
-        return BoundAction(self._client.actions, response['action'])
+        response = self._client.request(
+            url="/servers/{server_id}/actions/poweroff".format(server_id=server.id),
+            method="POST",
+        )
+        return BoundAction(self._client.actions, response["action"])
 
     def power_on(self, server):
         # type: (servers.domain.Server) -> actions.domain.Action
@@ -565,9 +627,11 @@ class ServersClient(ClientEntityBase, GetEntityByNameMixin):
         :param server: :class:`BoundServer <hcloud.servers.client.BoundServer>` or :class:`Server <hcloud.servers.domain.Server>`
         :return:  :class:`BoundAction <hcloud.actions.client.BoundAction>`
         """
-        response = self._client.request(url="/servers/{server_id}/actions/poweron".format(server_id=server.id),
-                                        method="POST")
-        return BoundAction(self._client.actions, response['action'])
+        response = self._client.request(
+            url="/servers/{server_id}/actions/poweron".format(server_id=server.id),
+            method="POST",
+        )
+        return BoundAction(self._client.actions, response["action"])
 
     def reboot(self, server):
         # type: (servers.domain.Server) -> actions.domain.Action
@@ -576,9 +640,11 @@ class ServersClient(ClientEntityBase, GetEntityByNameMixin):
         :param server: :class:`BoundServer <hcloud.servers.client.BoundServer>` or :class:`Server <hcloud.servers.domain.Server>`
         :return:  :class:`BoundAction <hcloud.actions.client.BoundAction>`
         """
-        response = self._client.request(url="/servers/{server_id}/actions/reboot".format(server_id=server.id),
-                                        method="POST")
-        return BoundAction(self._client.actions, response['action'])
+        response = self._client.request(
+            url="/servers/{server_id}/actions/reboot".format(server_id=server.id),
+            method="POST",
+        )
+        return BoundAction(self._client.actions, response["action"])
 
     def reset(self, server):
         # type: (servers.domain.Server) -> actions.domainAction
@@ -587,9 +653,11 @@ class ServersClient(ClientEntityBase, GetEntityByNameMixin):
         :param server: :class:`BoundServer <hcloud.servers.client.BoundServer>` or :class:`Server <hcloud.servers.domain.Server>`
         :return:  :class:`BoundAction <hcloud.actions.client.BoundAction>`
         """
-        response = self._client.request(url="/servers/{server_id}/actions/reset".format(server_id=server.id),
-                                        method="POST")
-        return BoundAction(self._client.actions, response['action'])
+        response = self._client.request(
+            url="/servers/{server_id}/actions/reset".format(server_id=server.id),
+            method="POST",
+        )
+        return BoundAction(self._client.actions, response["action"])
 
     def shutdown(self, server):
         # type: (servers.domain.Server) -> actions.domainAction
@@ -598,21 +666,29 @@ class ServersClient(ClientEntityBase, GetEntityByNameMixin):
         :param server: :class:`BoundServer <hcloud.servers.client.BoundServer>` or :class:`Server <hcloud.servers.domain.Server>`
         :return:  :class:`BoundAction <hcloud.actions.client.BoundAction>`
         """
-        response = self._client.request(url="/servers/{server_id}/actions/shutdown".format(server_id=server.id),
-                                        method="POST")
-        return BoundAction(self._client.actions, response['action'])
+        response = self._client.request(
+            url="/servers/{server_id}/actions/shutdown".format(server_id=server.id),
+            method="POST",
+        )
+        return BoundAction(self._client.actions, response["action"])
 
     def reset_password(self, server):
         # type: (servers.domain.Server) -> ResetPasswordResponse
-        """ Resets the root password. Only works for Linux systems that are running the qemu guest agent.
+        """Resets the root password. Only works for Linux systems that are running the qemu guest agent.
 
         :param server: :class:`BoundServer <hcloud.servers.client.BoundServer>` or :class:`Server <hcloud.servers.domain.Server>`
         :return: :class:`ResetPasswordResponse <hcloud.servers.domain.ResetPasswordResponse>`
         """
-        response = self._client.request(url="/servers/{server_id}/actions/reset_password".format(server_id=server.id),
-                                        method="POST")
-        return ResetPasswordResponse(action=BoundAction(self._client.actions, response['action']),
-                                     root_password=response['root_password'])
+        response = self._client.request(
+            url="/servers/{server_id}/actions/reset_password".format(
+                server_id=server.id
+            ),
+            method="POST",
+        )
+        return ResetPasswordResponse(
+            action=BoundAction(self._client.actions, response["action"]),
+            root_password=response["root_password"],
+        )
 
     def change_type(self, server, server_type, upgrade_disk):
         # type: (servers.domain.Server, BoundServerType, bool) -> actions.domainAction
@@ -625,13 +701,13 @@ class ServersClient(ClientEntityBase, GetEntityByNameMixin):
                If false, do not upgrade the disk. This allows downgrading the server type later.
         :return:  :class:`BoundAction <hcloud.actions.client.BoundAction>`
         """
-        data = {
-            "server_type": server_type.id_or_name,
-            "upgrade_disk": upgrade_disk
-        }
-        response = self._client.request(url="/servers/{server_id}/actions/change_type".format(server_id=server.id),
-                                        method="POST", json=data)
-        return BoundAction(self._client.actions, response['action'])
+        data = {"server_type": server_type.id_or_name, "upgrade_disk": upgrade_disk}
+        response = self._client.request(
+            url="/servers/{server_id}/actions/change_type".format(server_id=server.id),
+            method="POST",
+            json=data,
+        )
+        return BoundAction(self._client.actions, response["action"])
 
     def enable_rescue(self, server, type=None, ssh_keys=None):
         # type: (servers.domain.Server, str, Optional[List[str]]) -> EnableRescueResponse
@@ -645,16 +721,21 @@ class ServersClient(ClientEntityBase, GetEntityByNameMixin):
                 Array of SSH key IDs which should be injected into the rescue system. Only available for types: linux64 and linux32.
         :return: :class:`EnableRescueResponse <hcloud.servers.domain.EnableRescueResponse>`
         """
-        data = {
-            "type": type
-        }
+        data = {"type": type}
         if ssh_keys is not None:
             data.update({"ssh_keys": ssh_keys})
 
-        response = self._client.request(url="/servers/{server_id}/actions/enable_rescue".format(server_id=server.id),
-                                        method="POST", json=data)
-        return EnableRescueResponse(action=BoundAction(self._client.actions, response['action']),
-                                    root_password=response['root_password'])
+        response = self._client.request(
+            url="/servers/{server_id}/actions/enable_rescue".format(
+                server_id=server.id
+            ),
+            method="POST",
+            json=data,
+        )
+        return EnableRescueResponse(
+            action=BoundAction(self._client.actions, response["action"]),
+            root_password=response["root_password"],
+        )
 
     def disable_rescue(self, server):
         # type: (servers.domain.Server) -> actions.domainAction
@@ -663,9 +744,13 @@ class ServersClient(ClientEntityBase, GetEntityByNameMixin):
         :param server: :class:`BoundServer <hcloud.servers.client.BoundServer>` or :class:`Server <hcloud.servers.domain.Server>`
         :return:  :class:`BoundAction <hcloud.actions.client.BoundAction>`
         """
-        response = self._client.request(url="/servers/{server_id}/actions/disable_rescue".format(server_id=server.id),
-                                        method="POST")
-        return BoundAction(self._client.actions, response['action'])
+        response = self._client.request(
+            url="/servers/{server_id}/actions/disable_rescue".format(
+                server_id=server.id
+            ),
+            method="POST",
+        )
+        return BoundAction(self._client.actions, response["action"])
 
     def create_image(self, server, description=None, type=None, labels=None):
         # type: (servers.domain.Server, str, str, Optional[Dict[str, str]]) -> CreateImageResponse
@@ -691,10 +776,15 @@ class ServersClient(ClientEntityBase, GetEntityByNameMixin):
         if labels is not None:
             data.update({"labels": labels})
 
-        response = self._client.request(url="/servers/{server_id}/actions/create_image".format(server_id=server.id),
-                                        method="POST", json=data)
-        return CreateImageResponse(action=BoundAction(self._client.actions, response['action']),
-                                   image=BoundImage(self._client.images, response['image']))
+        response = self._client.request(
+            url="/servers/{server_id}/actions/create_image".format(server_id=server.id),
+            method="POST",
+            json=data,
+        )
+        return CreateImageResponse(
+            action=BoundAction(self._client.actions, response["action"]),
+            image=BoundImage(self._client.images, response["image"]),
+        )
 
     def rebuild(self, server, image):
         # type: (servers.domain.Server, Image) -> actions.domainAction
@@ -704,12 +794,13 @@ class ServersClient(ClientEntityBase, GetEntityByNameMixin):
         :param image: :class:`BoundImage <hcloud.images.client.BoundImage>` or :class:`Image <hcloud.servers.domain.Image>`
         :return:  :class:`BoundAction <hcloud.actions.client.BoundAction>`
         """
-        data = {
-            "image": image.id_or_name
-        }
-        response = self._client.request(url="/servers/{server_id}/actions/rebuild".format(server_id=server.id),
-                                        method="POST", json=data)
-        return BoundAction(self._client.actions, response['action'])
+        data = {"image": image.id_or_name}
+        response = self._client.request(
+            url="/servers/{server_id}/actions/rebuild".format(server_id=server.id),
+            method="POST",
+            json=data,
+        )
+        return BoundAction(self._client.actions, response["action"])
 
     def enable_backup(self, server):
         # type: (servers.domain.Server) -> actions.domainAction
@@ -718,9 +809,13 @@ class ServersClient(ClientEntityBase, GetEntityByNameMixin):
         :param server: :class:`BoundServer <hcloud.servers.client.BoundServer>` or :class:`Server <hcloud.servers.domain.Server>`
         :return:  :class:`BoundAction <hcloud.actions.client.BoundAction>`
         """
-        response = self._client.request(url="/servers/{server_id}/actions/enable_backup".format(server_id=server.id),
-                                        method="POST")
-        return BoundAction(self._client.actions, response['action'])
+        response = self._client.request(
+            url="/servers/{server_id}/actions/enable_backup".format(
+                server_id=server.id
+            ),
+            method="POST",
+        )
+        return BoundAction(self._client.actions, response["action"])
 
     def disable_backup(self, server):
         # type: (servers.domain.Server) -> actions.domainAction
@@ -729,9 +824,13 @@ class ServersClient(ClientEntityBase, GetEntityByNameMixin):
         :param server: :class:`BoundServer <hcloud.servers.client.BoundServer>` or :class:`Server <hcloud.servers.domain.Server>`
         :return: :class:`BoundAction <hcloud.actions.client.BoundAction>`
         """
-        response = self._client.request(url="/servers/{server_id}/actions/disable_backup".format(server_id=server.id),
-                                        method="POST")
-        return BoundAction(self._client.actions, response['action'])
+        response = self._client.request(
+            url="/servers/{server_id}/actions/disable_backup".format(
+                server_id=server.id
+            ),
+            method="POST",
+        )
+        return BoundAction(self._client.actions, response["action"])
 
     def attach_iso(self, server, iso):
         # type: (servers.domain.Server, Iso) -> actions.domainAction
@@ -741,12 +840,13 @@ class ServersClient(ClientEntityBase, GetEntityByNameMixin):
         :param iso: :class:`BoundIso <hcloud.isos.client.BoundIso>` or :class:`Server <hcloud.isos.domain.Iso>`
         :return:  :class:`BoundAction <hcloud.actions.client.BoundAction>`
         """
-        data = {
-            "iso": iso.id_or_name
-        }
-        response = self._client.request(url="/servers/{server_id}/actions/attach_iso".format(server_id=server.id),
-                                        method="POST", json=data)
-        return BoundAction(self._client.actions, response['action'])
+        data = {"iso": iso.id_or_name}
+        response = self._client.request(
+            url="/servers/{server_id}/actions/attach_iso".format(server_id=server.id),
+            method="POST",
+            json=data,
+        )
+        return BoundAction(self._client.actions, response["action"])
 
     def detach_iso(self, server):
         # type: (servers.domain.Server) -> actions.domainAction
@@ -755,9 +855,11 @@ class ServersClient(ClientEntityBase, GetEntityByNameMixin):
         :param server: :class:`BoundServer <hcloud.servers.client.BoundServer>` or :class:`Server <hcloud.servers.domain.Server>`
         :return:  :class:`BoundAction <hcloud.actions.client.BoundAction>`
         """
-        response = self._client.request(url="/servers/{server_id}/actions/detach_iso".format(server_id=server.id),
-                                        method="POST")
-        return BoundAction(self._client.actions, response['action'])
+        response = self._client.request(
+            url="/servers/{server_id}/actions/detach_iso".format(server_id=server.id),
+            method="POST",
+        )
+        return BoundAction(self._client.actions, response["action"])
 
     def change_dns_ptr(self, server, ip, dns_ptr):
         # type: (servers.domain.Server, str, str) -> actions.domainAction
@@ -770,13 +872,15 @@ class ServersClient(ClientEntityBase, GetEntityByNameMixin):
                   Hostname to set as a reverse DNS PTR entry, will reset to original default value if `None`
         :return:  :class:`BoundAction <hcloud.actions.client.BoundAction>`
         """
-        data = {
-            "ip": ip,
-            "dns_ptr": dns_ptr
-        }
-        response = self._client.request(url="/servers/{server_id}/actions/change_dns_ptr".format(server_id=server.id),
-                                        method="POST", json=data)
-        return BoundAction(self._client.actions, response['action'])
+        data = {"ip": ip, "dns_ptr": dns_ptr}
+        response = self._client.request(
+            url="/servers/{server_id}/actions/change_dns_ptr".format(
+                server_id=server.id
+            ),
+            method="POST",
+            json=data,
+        )
+        return BoundAction(self._client.actions, response["action"])
 
     def change_protection(self, server, delete=None, rebuild=None):
         # type: (servers.domain.Server, Optional[bool], Optional[bool]) -> actions.domainAction
@@ -796,8 +900,13 @@ class ServersClient(ClientEntityBase, GetEntityByNameMixin):
             data.update({"rebuild": rebuild})
 
         response = self._client.request(
-            url="/servers/{server_id}/actions/change_protection".format(server_id=server.id), method="POST", json=data)
-        return BoundAction(self._client.actions, response['action'])
+            url="/servers/{server_id}/actions/change_protection".format(
+                server_id=server.id
+            ),
+            method="POST",
+            json=data,
+        )
+        return BoundAction(self._client.actions, response["action"])
 
     def request_console(self, server):
         # type: (servers.domain.Server) -> RequestConsoleResponse
@@ -806,10 +915,17 @@ class ServersClient(ClientEntityBase, GetEntityByNameMixin):
         :param server: :class:`BoundServer <hcloud.servers.client.BoundServer>` or :class:`Server <hcloud.servers.domain.Server>`
         :return: :class:`RequestConsoleResponse <hcloud.servers.domain.RequestConsoleResponse>`
         """
-        response = self._client.request(url="/servers/{server_id}/actions/request_console".format(server_id=server.id),
-                                        method="POST")
-        return RequestConsoleResponse(action=BoundAction(self._client.actions, response['action']),
-                                      wss_url=response['wss_url'], password=response['password'])
+        response = self._client.request(
+            url="/servers/{server_id}/actions/request_console".format(
+                server_id=server.id
+            ),
+            method="POST",
+        )
+        return RequestConsoleResponse(
+            action=BoundAction(self._client.actions, response["action"]),
+            wss_url=response["wss_url"],
+            password=response["password"],
+        )
 
     def attach_to_network(self, server, network, ip=None, alias_ips=None):
         # type: (Union[Server,BoundServer], Union[Network,BoundNetwork],Optional[str], Optional[List[str]]) -> BoundAction
@@ -831,9 +947,13 @@ class ServersClient(ClientEntityBase, GetEntityByNameMixin):
         if alias_ips is not None:
             data.update({"alias_ips": alias_ips})
         response = self._client.request(
-            url="/servers/{server_id}/actions/attach_to_network".format(server_id=server.id), method="POST",
-            json=data)
-        return BoundAction(self._client.actions, response['action'])
+            url="/servers/{server_id}/actions/attach_to_network".format(
+                server_id=server.id
+            ),
+            method="POST",
+            json=data,
+        )
+        return BoundAction(self._client.actions, response["action"])
 
     def detach_from_network(self, server, network):
         # type: (Union[Server,BoundServer], Union[Network,BoundNetwork]) -> BoundAction
@@ -847,9 +967,13 @@ class ServersClient(ClientEntityBase, GetEntityByNameMixin):
             "network": network.id,
         }
         response = self._client.request(
-            url="/servers/{server_id}/actions/detach_from_network".format(server_id=server.id), method="POST",
-            json=data)
-        return BoundAction(self._client.actions, response['action'])
+            url="/servers/{server_id}/actions/detach_from_network".format(
+                server_id=server.id
+            ),
+            method="POST",
+            json=data,
+        )
+        return BoundAction(self._client.actions, response["action"])
 
     def change_alias_ips(self, server, network, alias_ips):
         # type: (Union[Server,BoundServer], Union[Network,BoundNetwork], List[str]) -> BoundAction
@@ -861,11 +985,12 @@ class ServersClient(ClientEntityBase, GetEntityByNameMixin):
                 New alias IPs to set for this server.
         :return: :class:`BoundAction <hcloud.actions.client.BoundAction>`
         """
-        data = {
-            "network": network.id,
-            "alias_ips": alias_ips
-        }
+        data = {"network": network.id, "alias_ips": alias_ips}
         response = self._client.request(
-            url="/servers/{server_id}/actions/change_alias_ips".format(server_id=server.id), method="POST",
-            json=data)
-        return BoundAction(self._client.actions, response['action'])
+            url="/servers/{server_id}/actions/change_alias_ips".format(
+                server_id=server.id
+            ),
+            method="POST",
+            json=data,
+        )
+        return BoundAction(self._client.actions, response["action"])
